@@ -39,3 +39,23 @@ class Client:
   def send_as_user(self, msg):
     j = {"send_as_user": msg}
     self._send(Client._encode_json(j))
+
+  def send_status(self, msg_id, msg):
+    j = {"send_status": {"id": msg_id, "msg": msg}}
+    self._send(Client._encode_json(j))
+
+  def send_error(self, msg):
+    j = {"send_warning": msg}
+    self._send(Client._encode_json(j))
+
+  def store(self, values_dict):
+    j = {"store_in_memory": values_dict}
+    self._send(Client._encode_json(j))
+    
+  def read(self, keys_arr, buffer_size=8192):
+    j = {"memory_cells": keys_arr}
+    j = Server._decode_json(self._accept(Client._encode_json(j), buffer_size))
+    if "memory_values" not in j:
+      return None
+    else:
+      return j
